import 'package:flutter/material.dart';

class Tab extends StatelessWidget {
  final Color color;
  final dynamic height;
  final dynamic width;
  final List<double>? radius;
  final List<double> padding;
  final List<double> margin;
  final double elevation;
  final Widget child;
  final bool? isCircle;
  final BorderSide border;
  final GestureTapCallback? onTap;
  const Tab({
    this.color = Colors.transparent,
    this.height = const [0, double.infinity],
    this.width = const [0, double.infinity],
    this.radius,
    this.padding = const [0, 0, 0, 0],
    this.margin = const [0, 0, 0, 0],
    this.isCircle = false,
    this.border = BorderSide.none,
    this.elevation = 0,
    required this.child,
    this.onTap,
  });

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.only(top: margin[0], right: margin[1], bottom: margin[2], left: margin[3]),
      child: ConstrainedBox(
        constraints: BoxConstraints(
          minHeight: isOne(height) ? height : height[0],
          maxHeight: isOne(height) ? height : height[1],
          minWidth: isOne(width) ? width : width[0],
          maxWidth: isOne(width) ? width : width[1],
        ),
        child: Material(
          color: color,
          elevation: elevation,
          shape: isCircle == false
              ? RoundedRectangleBorder(
                  borderRadius: radius == null
                      ? BorderRadius.zero
                      : BorderRadius.only(
                          topLeft: Radius.circular(radius![0]),
                          topRight: Radius.circular(radius![1]),
                          bottomRight: Radius.circular(radius![2]),
                          bottomLeft: Radius.circular(radius![3]),
                        ),
                  side: border)
              : CircleBorder(side: border),
          clipBehavior: Clip.hardEdge,
          child: InkWell(
            child: Padding(
              padding: EdgeInsets.only(top: padding[0], right: padding[1], bottom: padding[2], left: padding[3]),
              child: DefaultTextStyle(style: Theme.of(context).textTheme.bodyText1!, child: child),
            ),
            onTap: onTap,
          ),
        ),
      ),
    );
  }
}


bool isOne(dynamic height) {
  try {
    height as double;
    return true;
  } catch (e) {
    return false;
  }
}